Package: mets
Type: Package
Title: Analysis of Multivariate Event Times
Version: 1.2.9
Date: 2021-09-05
Authors@R: c(person("Klaus K.", "Holst", email="klaus@holst.it", role=c("aut", "cre")),
             person("Thomas Scheike", role=c("aut")))
Author: Klaus K. Holst [aut, cre],
  Thomas Scheike [aut]
Maintainer: Klaus K. Holst <klaus@holst.it>
Description: Implementation of various statistical models for multivariate
    event history data <doi:10.1007/s10985-013-9244-x>. Including multivariate
    cumulative incidence models <doi:10.1002/sim.6016>, and  bivariate random
    effects probit models (Liability models) <doi:10.1016/j.csda.2015.01.014>.
    Also contains two-stage binomial modelling that can do pairwise odds-ratio
    dependence modelling based marginal logistic regression models. This is an
    alternative to the alternating logistic regression approach (ALR).
License: GPL (>= 2)
LazyLoad: yes
URL: https://kkholst.github.io/mets/
BugReports: https://github.com/kkholst/mets/issues
Depends: R (>= 3.5), timereg (>= 1.9.4), lava (>= 1.6.6)
Imports: mvtnorm, numDeriv, compiler, Rcpp, splines, survival (>=
        2.43-1),
Suggests: optimx, prodlim, cmprsk, testthat (>= 0.11), ucminf, knitr,
        rmarkdown, ggplot2, cowplot, icenReg
VignetteBuilder: knitr
ByteCompile: yes
LinkingTo: Rcpp, RcppArmadillo, mvtnorm
SystemRequirements: C++11
Encoding: UTF-8
RoxygenNote: 7.1.1
NeedsCompilation: yes
Packaged: 2021-09-05 17:19:03 UTC; klaus
Repository: CRAN
Date/Publication: 2021-09-06 07:20:02 UTC
Built: R 4.1.1; x86_64-w64-mingw32; 2021-09-06 09:28:54 UTC; windows
Archs: x64
